@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2012 Razor team
  * Authors:
@@ -131,7 +131,8 @@ void GridLayoutPrivate::updateCache()
     mCellMaxSize = QSize(0, 0);
     mVisibleCount = 0;
 
-    for (int i=0; i<mItems.count(); ++i)
+    const int N = mItems.count();
+    for (int i=0; i < N; ++i)
     {
         QLayoutItem *item = mItems.at(i);
         if (!item->widget() || item->widget()->isHidden())
@@ -640,7 +641,7 @@ void GridLayout::setGeometry(const QRect &geometry)
     if (d->mDirection == LeftToRight)
     {
         int height = itemHeight + (0 < remain_height-- ? 1 : 0);
-        foreach(QLayoutItem *item, d->mItems)
+        for (QLayoutItem *item : qAsConst(d->mItems))
         {
             if (!item->widget() || item->widget()->isHidden())
                 continue;
@@ -663,7 +664,7 @@ void GridLayout::setGeometry(const QRect &geometry)
     else
     {
         int width = itemWidth + (0 < remain_width-- ? 1 : 0);
-        foreach(QLayoutItem *item, d->mItems)
+        for (QLayoutItem *item : qAsConst(d->mItems))
         {
             if (!item->widget() || item->widget()->isHidden())
                 continue;
