@@ -1,25 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="eo">
-<context>
-    <name>AddPluginDialog</name>
-    <message>
-        <source>Add plugins</source>
-        <translation type="obsolete">Aldoni kromprogramojn</translation>
-    </message>
-    <message>
-        <source>Search:</source>
-        <translation type="vanished">Serĉi:</translation>
-    </message>
-    <message>
-        <source>Add plugin</source>
-        <translation type="obsolete">Aldoni kromprogramon</translation>
-    </message>
-    <message>
-        <source>Close</source>
-        <translation type="vanished">Fermi</translation>
-    </message>
-</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -29,232 +10,187 @@
     </message>
 </context>
 <context>
-    <name>LxQt::AboutDialogPrivate</name>
+    <name>LXQt::MessageBox</name>
     <message>
-        <source>Yes</source>
-        <translation type="obsolete">Jes</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="obsolete">Ne</translation>
-    </message>
-</context>
-<context>
-    <name>LxQt::MessageBox</name>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="70"/>
-        <source>LxQt Power Manager Error</source>
+        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <source>LXQt Power Manager Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../lxqtpowermanager.cpp" line="74"/>
         <source>Hibernate failed.</source>
         <translation type="unfinished">Pasivumigo fiaskis.</translation>
     </message>
 </context>
 <context>
-    <name>LxQt::NotificationPrivate</name>
+    <name>LXQt::NotificationPrivate</name>
     <message>
-        <location filename="../lxqtnotification.cpp" line="152"/>
+        <location filename="../lxqtnotification.cpp" line="154"/>
         <source>Notifications Fallback</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>LxQt::PowerManager</name>
+    <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="112"/>
+        <location filename="../lxqtpowermanager.cpp" line="117"/>
         <source>Hibernate</source>
         <translation>Pasivumigi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="119"/>
+        <location filename="../lxqtpowermanager.cpp" line="124"/>
         <source>Suspend</source>
         <translation>Prokrasti</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="126"/>
+        <location filename="../lxqtpowermanager.cpp" line="131"/>
         <source>Reboot</source>
         <translation>Restartigi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="133"/>
+        <location filename="../lxqtpowermanager.cpp" line="138"/>
         <source>Shutdown</source>
         <translation>Elŝalti</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="140"/>
+        <location filename="../lxqtpowermanager.cpp" line="145"/>
         <source>Logout</source>
         <translation>Elsaluti</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="152"/>
-        <source>LxQt Session Suspend</source>
+        <location filename="../lxqtpowermanager.cpp" line="157"/>
+        <source>LXQt Session Suspend</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="153"/>
+        <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="162"/>
-        <source>LxQt Session Hibernate</source>
+        <location filename="../lxqtpowermanager.cpp" line="167"/>
+        <source>LXQt Session Hibernate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="163"/>
+        <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="172"/>
-        <source>LxQt Session Reboot</source>
+        <location filename="../lxqtpowermanager.cpp" line="177"/>
+        <source>LXQt Session Reboot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="173"/>
+        <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="182"/>
-        <source>LxQt Session Shutdown</source>
+        <location filename="../lxqtpowermanager.cpp" line="187"/>
+        <source>LXQt Session Shutdown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="183"/>
+        <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="192"/>
-        <source>LxQt Session Logout</source>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <source>LXQt Session Logout</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="193"/>
+        <location filename="../lxqtpowermanager.cpp" line="198"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="201"/>
         <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <source>LxQt Power Manager Error</source>
+        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <source>LXQt Power Manager Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="201"/>
+        <location filename="../lxqtpowermanager.cpp" line="206"/>
         <source>Hibernate failed.</source>
         <translation>Pasivumigo fiaskis.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="211"/>
         <source>Suspend failed.</source>
         <translation>Prokrasto fiaskis.</translation>
     </message>
 </context>
 <context>
-    <name>LxQt::ScreenSaver</name>
+    <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="51"/>
+        <location filename="../lxqtscreensaver.cpp" line="236"/>
         <source>Lock Screen</source>
         <translation>Ŝlosi ekranon</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="70"/>
-        <location filename="../lxqtscreensaver.cpp" line="78"/>
-        <location filename="../lxqtscreensaver.cpp" line="86"/>
-        <location filename="../lxqtscreensaver.cpp" line="98"/>
-        <location filename="../lxqtscreensaver.cpp" line="106"/>
-        <location filename="../lxqtscreensaver.cpp" line="114"/>
-        <location filename="../lxqtscreensaver.cpp" line="123"/>
+        <location filename="../lxqtscreensaver.cpp" line="156"/>
+        <source>Screen Saver Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="162"/>
+        <location filename="../lxqtscreensaver.cpp" line="168"/>
+        <location filename="../lxqtscreensaver.cpp" line="175"/>
         <source>Screen Saver Activation Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="71"/>
-        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
+        <location filename="../lxqtscreensaver.cpp" line="176"/>
+        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="79"/>
-        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="87"/>
-        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="99"/>
+        <location filename="../lxqtscreensaver.cpp" line="157"/>
         <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="107"/>
+        <location filename="../lxqtscreensaver.cpp" line="163"/>
         <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="115"/>
+        <location filename="../lxqtscreensaver.cpp" line="169"/>
         <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="124"/>
-        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
-    <name>LxQt::ShortcutButton</name>
+    <name>QCoreApplication</name>
     <message>
-        <source>Clear</source>
-        <translation type="obsolete">Vakigi</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="obsolete">Nenio</translation>
+        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
+        <source>Choose the page to be shown.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
         <translation>QDBusInterface nevalidas</translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>about</name>
-    <message>
-        <source> About LXQt</source>
-        <translation type="vanished"> Pri LxQto</translation>
-    </message>
-    <message>
-        <source>About</source>
-        <comment>About dialog, Tab title </comment>
-        <translation type="vanished">Pri</translation>
-    </message>
-    <message>
-        <source>Technical Info</source>
-        <comment>About dialog, Tab title</comment>
-        <translation type="vanished">Teknikaj informoj</translation>
-    </message>
-</context>
 </TS>
